/*******************************************************************************
* File Name: DAC.c
* Version 2.10
*
* Description:
*  This file provides the source code for the 8-bit Waveform DAC 
*  (WaveDAC8) Component.
*
********************************************************************************
* Copyright 2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "DAC.h"

uint8  DAC_initVar = 0u;

const uint8 CYCODE DAC_wave1[DAC_WAVE1_LENGTH] = { 128u,131u,135u,139u,143u,147u,151u,155u,159u,162u,166u,170u,174u,177u,181u,184u,188u,191u,194u,198u,201u,204u,207u,210u,213u,216u,219u,221u,224u,226u,229u,231u,233u,235u,237u,239u,241u,242u,244u,245u,246u,248u,249u,249u,250u,251u,252u,252u,252u,252u,252u,252u,252u,252u,252u,251u,250u,249u,249u,248u,246u,245u,244u,242u,241u,239u,237u,235u,233u,231u,229u,226u,224u,221u,219u,216u,213u,210u,207u,204u,201u,198u,194u,191u,188u,184u,181u,177u,174u,170u,166u,162u,159u,155u,151u,147u,143u,139u,135u,131u,128u,124u,120u,116u,112u,108u,104u,100u,96u,93u,89u,85u,81u,78u,74u,71u,67u,64u,61u,57u,54u,51u,48u,45u,42u,39u,36u,34u,31u,29u,26u,24u,22u,20u,18u,16u,14u,13u,11u,10u,9u,7u,6u,6u,5u,4u,3u,3u,3u,3u,3u,3u,3u,3u,3u,4u,5u,6u,6u,7u,9u,10u,11u,13u,14u,16u,18u,20u,22u,24u,26u,29u,31u,34u,36u,39u,42u,45u,48u,51u,54u,57u,61u,64u,67u,71u,74u,78u,81u,85u,89u,93u,96u,100u,104u,108u,112u,116u,120u,124u };
const uint8 CYCODE DAC_wave2[DAC_WAVE2_LENGTH] = { 252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,252u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u,3u };

static uint8  DAC_Wave1Chan;
static uint8  DAC_Wave2Chan;
static uint8  DAC_Wave1TD;
static uint8  DAC_Wave2TD;


/*******************************************************************************
* Function Name: DAC_Init
********************************************************************************
*
* Summary:
*  Initializes component with parameters set in the customizer.
*
* Parameters:  
*  None
*
* Return: 
*  None
*
*******************************************************************************/
void DAC_Init(void) 
{
	DAC_VDAC8_Init();
	DAC_VDAC8_SetSpeed(DAC_HIGHSPEED);
	DAC_VDAC8_SetRange(DAC_DAC_RANGE);

	#if(DAC_DAC_MODE == DAC_CURRENT_MODE)
		DAC_IDAC8_SetPolarity(DAC_DAC_POL);
	#endif /* DAC_DAC_MODE == DAC_CURRENT_MODE */

	#if(DAC_OUT_MODE == DAC_BUFFER_MODE)
	   DAC_BuffAmp_Init();
	#endif /* DAC_OUT_MODE == DAC_BUFFER_MODE */

	/* Get the TD Number for the DMA channel 1 and 2   */
	DAC_Wave1TD = CyDmaTdAllocate();
	DAC_Wave2TD = CyDmaTdAllocate();
	
	/* Initialize waveform pointers  */
	DAC_Wave1Setup(DAC_wave1, DAC_WAVE1_LENGTH) ;
	DAC_Wave2Setup(DAC_wave2, DAC_WAVE2_LENGTH) ;
	
	/* Initialize the internal clock if one present  */
	#if defined(DAC_DacClk_PHASE)
	   DAC_DacClk_SetPhase(DAC_CLK_PHASE_0nS);
	#endif /* defined(DAC_DacClk_PHASE) */
}


/*******************************************************************************
* Function Name: DAC_Enable
********************************************************************************
*  
* Summary: 
*  Enables the DAC block and DMA operation.
*
* Parameters:  
*  None
*
* Return: 
*  None
*
*******************************************************************************/
void DAC_Enable(void) 
{
	DAC_VDAC8_Enable();

	#if(DAC_OUT_MODE == DAC_BUFFER_MODE)
	   DAC_BuffAmp_Enable();
	#endif /* DAC_OUT_MODE == DAC_BUFFER_MODE */

	/* 
	* Enable the channel. It is configured to remember the TD value so that
	* it can be restored from the place where it has been stopped.
	*/
	(void)CyDmaChEnable(DAC_Wave1Chan, 1u);
	(void)CyDmaChEnable(DAC_Wave2Chan, 1u);
	
	/* set the initial value */
	DAC_SetValue(0u);
	
	#if(DAC_CLOCK_SRC == DAC_CLOCK_INT)  	
	   DAC_DacClk_Start();
	#endif /* DAC_CLOCK_SRC == DAC_CLOCK_INT */
}


/*******************************************************************************
* Function Name: DAC_Start
********************************************************************************
*
* Summary:
*  The start function initializes the voltage DAC with the default values, 
*  and sets the power to the given level.  A power level of 0, is the same as 
*  executing the stop function.
*
* Parameters:  
*  None
*
* Return: 
*  None
*
* Reentrant:
*  No
*
*******************************************************************************/
void DAC_Start(void) 
{
	/* If not Initialized then initialize all required hardware and software */
	if(DAC_initVar == 0u)
	{
		DAC_Init();
		DAC_initVar = 1u;
	}
	
	DAC_Enable();
}


/*******************************************************************************
* Function Name: DAC_StartEx
********************************************************************************
*
* Summary:
*  The StartEx function sets pointers and sizes for both waveforms
*  and then starts the component.
*
* Parameters:  
*   uint8 * wavePtr1:     Pointer to the waveform 1 array.
*   uint16  sampleSize1:  The amount of samples in the waveform 1.
*   uint8 * wavePtr2:     Pointer to the waveform 2 array.
*   uint16  sampleSize2:  The amount of samples in the waveform 2.
*
* Return: 
*  None
*
* Reentrant:
*  No
*
*******************************************************************************/
void DAC_StartEx(const uint8 * wavePtr1, uint16 sampleSize1, const uint8 * wavePtr2, uint16 sampleSize2)

{
	DAC_Wave1Setup(wavePtr1, sampleSize1);
	DAC_Wave2Setup(wavePtr2, sampleSize2);
	DAC_Start();
}


/*******************************************************************************
* Function Name: DAC_Stop
********************************************************************************
*
* Summary:
*  Stops the clock (if internal), disables the DMA channels
*  and powers down the DAC.
*
* Parameters:  
*  None  
*
* Return: 
*  None
*
*******************************************************************************/
void DAC_Stop(void) 
{
	/* Turn off internal clock, if one present */
	#if(DAC_CLOCK_SRC == DAC_CLOCK_INT)  	
	   DAC_DacClk_Stop();
	#endif /* DAC_CLOCK_SRC == DAC_CLOCK_INT */
	
	/* Disble DMA channels */
	(void)CyDmaChDisable(DAC_Wave1Chan);
	(void)CyDmaChDisable(DAC_Wave2Chan);

	/* Disable power to DAC */
	DAC_VDAC8_Stop();
}


/*******************************************************************************
* Function Name: DAC_Wave1Setup
********************************************************************************
*
* Summary:
*  Sets pointer and size for waveform 1.                                    
*
* Parameters:  
*  uint8 * WavePtr:     Pointer to the waveform array.
*  uint16  SampleSize:  The amount of samples in the waveform.
*
* Return: 
*  None 
*
*******************************************************************************/
void DAC_Wave1Setup(const uint8 * wavePtr, uint16 sampleSize)

{
	#if (CY_PSOC3)
		uint16 memoryType; /* determining the source memory type */
		memoryType = (DAC_HI16FLASHPTR == HI16(wavePtr)) ? HI16(CYDEV_FLS_BASE) : HI16(CYDEV_SRAM_BASE);
		
		DAC_Wave1Chan = DAC_Wave1_DMA_DmaInitialize(
		DAC_Wave1_DMA_BYTES_PER_BURST, DAC_Wave1_DMA_REQUEST_PER_BURST,
		memoryType, HI16(CYDEV_PERIPH_BASE));
	#else /* PSoC 5 */
		DAC_Wave1Chan = DAC_Wave1_DMA_DmaInitialize(
		DAC_Wave1_DMA_BYTES_PER_BURST, DAC_Wave1_DMA_REQUEST_PER_BURST,
		HI16(wavePtr), HI16(DAC_DAC8__D));
	#endif /* CY_PSOC3 */
	
	/*
	* TD is looping on itself. 
    * Increment the source address, but not the destination address. 
	*/
	(void)CyDmaTdSetConfiguration(DAC_Wave1TD, sampleSize, DAC_Wave1TD, 
                                    (uint8)CY_DMA_TD_INC_SRC_ADR | (uint8)DAC_Wave1_DMA__TD_TERMOUT_EN); 
	
	/* Set the TD source and destination address */
	(void)CyDmaTdSetAddress(DAC_Wave1TD, LO16((uint32)wavePtr), LO16(DAC_DAC8__D));
	
	/* Associate the TD with the channel */
	(void)CyDmaChSetInitialTd(DAC_Wave1Chan, DAC_Wave1TD);
}


/*******************************************************************************
* Function Name: DAC_Wave2Setup
********************************************************************************
*
* Summary:
*  Sets pointer and size for waveform 2.                                    
*
* Parameters:  
*  uint8 * WavePtr:     Pointer to the waveform array.
*  uint16  SampleSize:  The amount of samples in the waveform.
*
* Return: 
*  None
*
*******************************************************************************/
void DAC_Wave2Setup(const uint8 * wavePtr, uint16 sampleSize)
 
{
	#if (CY_PSOC3)
		uint16 memoryType; /* determining the source memory type */
		memoryType = (DAC_HI16FLASHPTR == HI16(wavePtr)) ? HI16(CYDEV_FLS_BASE) : HI16(CYDEV_SRAM_BASE);
			
		DAC_Wave2Chan = DAC_Wave2_DMA_DmaInitialize(
		DAC_Wave2_DMA_BYTES_PER_BURST, DAC_Wave2_DMA_REQUEST_PER_BURST,
		memoryType, HI16(CYDEV_PERIPH_BASE));
	#else /* PSoC 5 */
		DAC_Wave2Chan = DAC_Wave2_DMA_DmaInitialize(
		DAC_Wave2_DMA_BYTES_PER_BURST, DAC_Wave2_DMA_REQUEST_PER_BURST,
		HI16(wavePtr), HI16(DAC_DAC8__D));
	#endif /* CY_PSOC3 */
	
	/*
	* TD is looping on itself. 
	* Increment the source address, but not the destination address. 
	*/
	(void)CyDmaTdSetConfiguration(DAC_Wave2TD, sampleSize, DAC_Wave2TD, 
                                    (uint8)CY_DMA_TD_INC_SRC_ADR | (uint8)DAC_Wave2_DMA__TD_TERMOUT_EN); 
	
	/* Set the TD source and destination address */
	(void)CyDmaTdSetAddress(DAC_Wave2TD, LO16((uint32)wavePtr), LO16(DAC_DAC8__D));
	
	/* Associate the TD with the channel */
	(void)CyDmaChSetInitialTd(DAC_Wave2Chan, DAC_Wave2TD);
}


/* [] END OF FILE */
